Ports
======

.. _Port_Subtypes:


.. toctree::
   :maxdepth: 1

   *Subclasses:*
   InputPort
   ParameterPort
   OutputPort
   ModulatorySignals <ModulatorySignal>

.. automodule:: psyneulink.core.components.ports.port
   :members:
   :exclude-members: random, update, Parameters

